@@ -531,7 +531,8 @@ class TestNetworkElement(unittest.TestCase):
             'pingable': None
         })
         self.ctx.snmp_client_cls.connection_lost = False
-        self._await(ne.poll())
+        # manual poll!
+        self._await(ne._poll())
         self._await(asyncio.sleep(2)) # TODO better way to wait etc...
         self._await(self.reg.check_status())
         self.assertEqual(len(self.ctx.metrics),2)
@@ -591,7 +592,7 @@ class TestNetworkElement(unittest.TestCase):
             'holdoff': HOLD_OFF-1
         })
         self.ctx.snmp_client_cls.connection_lost = False
-        self._await(ne.poll())
+        self._await(ne._poll())
         self._await(asyncio.sleep(2)) # TODO better way to wait etc...
         self.assertEqual(len(self.ctx.metrics),1)
         fm = self.ctx.metrics.pop(-1)
@@ -952,12 +953,12 @@ class TestNetworkElement(unittest.TestCase):
 
         # An AP uses matching credentials.
         ne = self._setup_mikrotik_ne('ap', cfg)
-        self._await(ne.poll())
+        self._await(ne._poll())
         self.assertEqual(set(FakeMikrotikClient.attempted_logins), ap_creds)
 
         # A router uses matching credentials.
         ne = self._setup_mikrotik_ne('router', cfg)
-        self._await(ne.poll())
+        self._await(ne._poll())
         self.assertEqual(set(FakeMikrotikClient.attempted_logins), router_creds)
 
     def test_send_update_1(self):
@@ -1044,11 +1045,13 @@ class TestNetworkElement(unittest.TestCase):
         #disable_bad_data_range_error = True
         ne.set_element_status(ne_msg, ne_errctx)
         self.assertEqual(len(ne_msg.errors), 0)
+        self.assertEqual(ne_msg.status, network_poller_pb2.ELEMENT_STATUS_ONLINE)
 
         #disable_bad_data_range_error = False
         cfg['disable_bad_data_range_error'] = False
         ne.set_element_status(ne_msg, ne_errctx)
         self.assertEqual(len(ne_msg.errors), 1)
+        self.assertEqual(ne_msg.status, network_poller_pb2.ELEMENT_STATUS_ERROR)
 
 
     def test_suppress_offline_update_to_agent_polled_element(self):
